nest_asyncio: Patch asyncio to allow nested event loops
=======================================================

Description
-----------

Patch asyncio to allow nested event loops

License
-------

BSD

Upstream Contact
----------------

https://pypi.org/project/nest-asyncio/

